Welcome to {{ project }}'s documentation!
=======================================

.. include:: warning.rst

.. include:: ../README.rst

.. toctree::
   :maxdepth: 2

   Installation instructions <install.rst>
   API documentation <apidoc.rst>
   License <license.rst>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

